/*
 * account.c
 */

#define LIBNFSNAPI_BUILDING_LIB

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "account.h"
#include "error.h"
#include "mgr.h"


libnfsnapi_account_t *libnfsnapi_account_create(libnfsnapi_mgr_t *mgr,
						const char *account_id)
{
	libnfsnapi_account_t *account;

	account = (libnfsnapi_account_t *) malloc(sizeof(libnfsnapi_account_t));
	if (!account) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return NULL;
	}

	account->mgr = mgr;

	/* TODO: check format of Account ID */

	account->account_id = strdup(account_id);
	if (!account->account_id) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		free(account);
		return NULL;
	}

	return account;
}

void libnfsnapi_account_destroy(libnfsnapi_account_t *account)
{
	free(account->account_id);
	free(account);
}

/* Returns balance in cents, or a negative number on error. */
int libnfsnapi_account_balance(libnfsnapi_account_t *account,
				libnfsnapi_account_balance_t type)
{
	const char *prop;
	char *request_uri;
	int err;

	switch (type) {
#define B(x)	case LIBNFSNAPI_BALANCE_##x
		B(ALL):		prop = "balance"; break;
		B(CASH):	prop = "balanceCash"; break;
		B(CREDIT):	prop = "balanceCredit"; break;
		B(HIGH):	prop = "balanceHigh"; break;
		default:
			account->mgr->error = LIBNFSNAPI_ERROR_ARGUMENT;
			return -1;
	}

	asprintf(&request_uri, "/account/%s/%s", account->account_id, prop);
	if (!request_uri) {
		account->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}
	err = libnfsnapi_mgr_do(account->mgr, LIBNFSNAPI_MGR_HTTP_GET,
				request_uri, NULL);
	free(request_uri);

	if (err)
		return -1;

	/* TODO: retrieve response string and parse more carefully */
	float bal = libnfsnapi_mgr_result_float(account->mgr) * 100;
	int bal_i = bal;

	return bal_i;
}

char *libnfsnapi_account_friendlyName(libnfsnapi_account_t *account)
{
	char *request_uri;
	int err;

	asprintf(&request_uri, "/account/%s/friendlyName", account->account_id);
	if (!request_uri) {
		account->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return NULL;
	}
	err = libnfsnapi_mgr_do(account->mgr, LIBNFSNAPI_MGR_HTTP_GET,
			request_uri, NULL);
	free(request_uri);

	if (err)
		return NULL;

	/* TODO: retrieve response string and parse more carefully */
	return libnfsnapi_mgr_result_string(account->mgr);
}
