/*
 * account.h
 */

#ifndef __LIBNFSNAPI_ACCOUNT_H__
#define __LIBNFSNAPI_ACCOUNT_H__

/**
 * @defgroup Account
 *
 * @{
 */

#include "mgr.h"

/** Account handle. Users should treat this structure as opaque. */
typedef struct {
#ifdef LIBNFSNAPI_BUILDING_LIB
	/* Opaque! Don't touch anything here! */
	libnfsnapi_mgr_t *mgr;

	char *account_id;
#endif
} libnfsnapi_account_t;

/** See \ref libnfsnapi_account_balance. */
typedef enum {
	LIBNFSNAPI_BALANCE_ALL = 0,
	LIBNFSNAPI_BALANCE_CASH = 1,
	LIBNFSNAPI_BALANCE_CREDIT = 2,
	LIBNFSNAPI_BALANCE_HIGH = 3
} libnfsnapi_account_balance_t;

/**
 * Create an Account object.
 *
 * @param mgr A Manager object, created with \ref libnfsnapi_mgr_create.
 * @param account_id A 12-digit NFSN account number, in the form
 *			XXXX-XXXXXXXX. It will be copied internally.
 * \return An Account object, or NULL on failure.
 */
libnfsnapi_account_t *libnfsnapi_account_create(libnfsnapi_mgr_t *mgr,
						const char *account_id);
/**
 * Destroy an Account object, and free all memory associated with it.
 * Do not use this pointer after calling this function.
 */
void libnfsnapi_account_destroy(libnfsnapi_account_t *account);
/**
 * Retrieve the account's balance.
 *
 * @param account An Account object.
 * @param type The balance to retrieve:
 *	\arg \c BALANCE_ALL	Current account balance (cash + credit).
 *	\arg \c BALANCE_CASH	Current account cash balance.
 *	\arg \c BALANCE_CREDIT	Current account credit (non-refundable) balance.
 *	\arg \c BALANCE_HIGH	Highest account balance ever recorded.
 * \return Account's balance in US cents, or a negative number on error.
 *		Use \ref libnfsnapi_mgr_error to find out the error code.
 */
int libnfsnapi_account_balance(libnfsnapi_account_t *account,
				libnfsnapi_account_balance_t type);
/**
 * Retrieve the account's human-friendly name.
 *
 * \return Account's friendly name. You should \c free the returned string
 *		when you've finished with it.
 */
char *libnfsnapi_account_friendlyName(libnfsnapi_account_t *account);

/** @} */

#endif /* __LIBNFSNAPI_ACCOUNT_H__ */
