/*
 * email.c
 */

#define LIBNFSNAPI_BUILDING_LIB

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "email.h"
#include "error.h"
#include "mgr.h"


libnfsnapi_email_t *libnfsnapi_email_create(libnfsnapi_mgr_t *mgr,
						const char *domain)
{
	libnfsnapi_email_t *email;

	email = (libnfsnapi_email_t *) malloc(sizeof(libnfsnapi_email_t));
	if (!email) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return NULL;
	}

	email->mgr = mgr;

	email->domain = strdup(domain);
	if (!email->domain) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		free(email);
		return NULL;
	}

	return email;
}

void libnfsnapi_email_destroy(libnfsnapi_email_t *email)
{
	free(email->domain);
	free(email);
}

int libnfsnapi_email_setForward(libnfsnapi_email_t *email, const char *forward,
				const char *dest_email)
{
	char *request_uri, *post_data;
	int err;

	/* TODO: any escaping required? */
	asprintf(&post_data, "forward=%s&dest_email=%s", forward, dest_email);
	if (!post_data) {
		email->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}

	asprintf(&request_uri, "/email/%s/setForward", email->domain);
	if (!request_uri) {
		free(post_data);
		email->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}
	err = libnfsnapi_mgr_do(email->mgr, LIBNFSNAPI_MGR_HTTP_POST,
				request_uri, post_data);
	free(request_uri);
	free(post_data);

	/* TODO: check result */

	return err;
}

int libnfsnapi_email_removeForward(libnfsnapi_email_t *email,
					const char *forward)
{
	char *request_uri, *post_data;
	int err;

	asprintf(&post_data, "forward=%s", forward);
	if (!post_data) {
		email->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}

	asprintf(&request_uri, "/email/%s/removeForward", email->domain);
	if (!request_uri) {
		free(post_data);
		email->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}
	err = libnfsnapi_mgr_do(email->mgr, LIBNFSNAPI_MGR_HTTP_POST,
				request_uri, post_data);
	free(request_uri);
	free(post_data);

	/* TODO: check result */

	return err;
}
