/*
 * email.h
 */

#ifndef __LIBNFSNAPI_EMAIL_H__
#define __LIBNFSNAPI_EMAIL_H__

/**
 * @defgroup Email
 *
 * @{
 */

#include "mgr.h"

/** Email handle. Users should treat this structure as opaque. */
typedef struct {
#ifdef LIBNFSNAPI_BUILDING_LIB
	/* Opaque! Don't touch anything here! */
	libnfsnapi_mgr_t *mgr;

	char *domain;
#endif
} libnfsnapi_email_t;

/**
 * Create an Email object.
 *
 * @param mgr A Manager object, created with \ref libnfsnapi_mgr_create.
 * @param domain The domain name. It will be copied internally.
 * \return An Email object, or NULL on failure.
 */
libnfsnapi_email_t *libnfsnapi_email_create(libnfsnapi_mgr_t *mgr,
						const char *domain);
/**
 * Destroy an Email object, and free all memory associated with it.
 * Do not use this pointer after calling this function.
 */
void libnfsnapi_email_destroy(libnfsnapi_email_t *email);
/**
 * Add a new email forwarding address. If the specified forward already
 * exists, it will be overwritten.
 *
 * @param email The Email object.
 * @param forward The username component of the email address to forward.
 * @param dest_email The destination email address.
 * \return Zero on success.
 * \todo Parse response to check for actual success/failure.
 * \todo Add comment about {bounce,discard}\@nearlyfreespeech.net.
 */
int libnfsnapi_email_setForward(libnfsnapi_email_t *email, const char *forward,
				const char *dest_email);
/**
 * Remove an email forwarding address.
 *
 * @param email The Email object.
 * @param forward The username component of the email address to remove.
 * \return Zero on success.
 * \todo Parse response to check for actual success/failure.
 */
int libnfsnapi_email_removeForward(libnfsnapi_email_t *email,
					const char *forward);

/** @} */

#endif /* __LIBNFSNAPI_EMAIL_H__ */
