/*
 * error.h
 */

#ifndef __LIBNFSNAPI_ERROR_H__
#define __LIBNFSNAPI_ERROR_H__

/**
 * @defgroup Error Error handling
 *
 * Errors and failures are indicated in several different ways throughout
 * libNFSNapi, such as returning \c NULL, or a non-zero value. To determine
 * the precise nature of the error, an <em>error code</em> is often available,
 * either as a return value from a function, or via \ref libnfsnapi_mgr_error.
 *
 * These error codes always reference a member of the \ref libnfsnapi_error_t
 * enumeration; they can be turned into human-readable messages by using the
 * \ref libnfsnapi_strerror function.
 *
 * @{
 */

/** Error codes returned by various libNFSNapi functions. */
typedef enum {
	LIBNFSNAPI_ERROR_NONE = 0,	/**< No error. */
	LIBNFSNAPI_ERROR_NOTIMPLEMENTED = 1,	/**< Not in libNFSNapi yet. */
	LIBNFSNAPI_ERROR_MEMORY = 2,	/**< Out of memory. */
	LIBNFSNAPI_ERROR_NETWORK = 3,	/**< A networking error. */
	LIBNFSNAPI_ERROR_LIBCURL = 4,	/**< A problem with libcurl. */
	LIBNFSNAPI_ERROR_ARGUMENT = 5,	/**< A bad argument was given. */
	LIBNFSNAPI_ERROR_PROTOCOL = 6,	/**< Server broke the API protocol. */
} libnfsnapi_error_t;

/**
 * Return a textual description of an error.
 *
 * @param error The error code to query.
 * \return Error description. Do not modify or \c free it.
 */
const char *libnfsnapi_strerror(libnfsnapi_error_t error);

/** @} */

#endif /* __LIBNFSNAPI_ERROR_H__ */
