/*
 * site.c
 */

#define LIBNFSNAPI_BUILDING_LIB

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "error.h"
#include "mgr.h"
#include "site.h"


libnfsnapi_site_t *libnfsnapi_site_create(libnfsnapi_mgr_t *mgr,
						const char *short_name)
{
	libnfsnapi_site_t *site;

	site = (libnfsnapi_site_t *) malloc(sizeof(libnfsnapi_site_t));
	if (!site) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return NULL;
	}

	site->mgr = mgr;

	site->short_name = strdup(short_name);
	if (!site->short_name) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		free(site);
		return NULL;
	}

	return site;
}

void libnfsnapi_site_destroy(libnfsnapi_site_t *site)
{
	free(site->short_name);
	free(site);
}

int libnfsnapi_site_addAlias(libnfsnapi_site_t *site, const char *alias)
{
	char *request_uri, *post_data;
	int err;

	asprintf(&post_data, "alias=%s", alias);

	asprintf(&request_uri, "/site/%s/addAlias", site->short_name);
	err = libnfsnapi_mgr_do(site->mgr, LIBNFSNAPI_MGR_HTTP_POST,
				request_uri, post_data);
	free(request_uri);
	free(post_data);

	/* TODO: check result */

	return err;
}

int libnfsnapi_site_removeAlias(libnfsnapi_site_t *site, const char *alias)
{
	char *request_uri, *post_data;
	int err;

	asprintf(&post_data, "alias=%s", alias);

	asprintf(&request_uri, "/site/%s/removeAlias", site->short_name);
	err = libnfsnapi_mgr_do(site->mgr, LIBNFSNAPI_MGR_HTTP_POST,
				request_uri, post_data);
	free(request_uri);
	free(post_data);

	/* TODO: check result */

	return err;
}
