/*
 * site.h
 */

#ifndef __LIBNFSNAPI_SITE_H__
#define __LIBNFSNAPI_SITE_H__

/**
 * @defgroup Site
 *
 * @{
 */

#include "mgr.h"

/** Site handle. Users should treat this structure as opaque. */
typedef struct {
#ifdef LIBNFSNAPI_BUILDING_LIB
	/* Opaque! Don't touch anything here! */
	libnfsnapi_mgr_t *mgr;

	char *short_name;
#endif
} libnfsnapi_site_t;

/**
 * Create a Site object.
 *
 * @param mgr A Manager object, created with \ref libnfsnapi_mgr_create.
 * @param short_name The site's short name. For example, if the site can be
 *			accessed as \c example.nfshost.com, then the short name
 *			is \c example. It will be copied internally.
 * \return A Site object, or NULL on failure.
 */
libnfsnapi_site_t *libnfsnapi_site_create(libnfsnapi_mgr_t *mgr,
						const char *short_name);
/**
 * Destroy a Site object, and free all memory associated with it.
 * Do not use this pointer after calling this function.
 */
void libnfsnapi_site_destroy(libnfsnapi_site_t *site);
/**
 * Add a new alias for the site.
 *
 * @param site The Site object.
 * @param alias The new alias.
 * \return Zero on success.
 * \todo Parse response to check for actual success/failure.
 */
int libnfsnapi_site_addAlias(libnfsnapi_site_t *site, const char *alias);
/**
 * Remove an alias for the site.
 *
 * @param site The Site object.
 * @param alias The alias to remove.
 * \return Zero on success.
 * \todo Parse response to check for actual success/failure.
 */
int libnfsnapi_site_removeAlias(libnfsnapi_site_t *site, const char *alias);

/** @} */

#endif /* __LIBNFSNAPI_SITE_H__ */
