/*
 * basic.c -- A basic test of libNFSNapi
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <libnfsnapi.h>



static char api_key[17];
static char acct_num[14];

/* Load the first 16 bytes from the file; return zero on success. */
/* Also, try to load an account number from the next line of it */
int load_api_key()
{
	char path[200], buf[50];
	FILE *f;

	sprintf(path, "%s/.nfsn-apikey", getenv("HOME"));

	f = fopen(path, "r");
	if (!f) {
		perror("fopen");
		return 1;
	}

	printf("Loading API key from %s... ", path);
	if (!fgets(buf, sizeof(buf), f)) {
		printf ("d'oh!\n");
		perror("fgets");
		fclose(f);
		return 1;
	}
	while (strchr("\r\n", buf[strlen(buf) - 1]))
		buf[strlen(buf) - 1] = '\0';
	if (strlen(buf) != 16) {
		printf ("hey!\nAPI keys are 16 characters!\n");
		fclose(f);
		return 1;
	}
	strcpy(api_key, buf);
	printf("[%s]\n", api_key);

	acct_num[0] = '\0';
	printf("Looking for account number on next line... ");
	if (feof(f) || !fgets(buf, sizeof(buf), f)) {
		printf ("nope!\n");
		fclose(f);
		return 0;
	}
	while (strchr("\r\n", buf[strlen(buf) - 1]))
		buf[strlen(buf) - 1] = '\0';
	if (strlen(buf) != 13) {
		printf ("hey!\nAccount numbers are 13 characters!\n");
		fclose(f);
		return 1;
	}
	strcpy(acct_num, buf);
	printf("[%s]\n", acct_num);

	fclose(f);
	return 0;
}

int main(void)
{
	libnfsnapi_mgr_t *mgr;
	libnfsnapi_account_t *account;
	int err;

	if (load_api_key() != 0) {
		printf("There's something wrong with ~/.nfsn-apikey!\n");
		printf("It should look something like this:\n");
		printf("\tp3kxmRKf9dk3l6ls\n");
		printf("\t1234-56789012\n");
		printf("The first line is your API key (required!)\n");
		printf("The second line is an account number (optional)\n");
		exit(1);
	}

	printf("Testing libNFSNapi...\n");

	mgr = libnfsnapi_mgr_create("dsymonds", api_key, &err);
	if (!mgr) {
		printf("Damn! libnfsnapi_mgr_create failed!\n");
		printf("Error: %s\n", libnfsnapi_strerror(err));
		exit(1);
	}

	/* NFSN's API server used to lag by about 27s; this isn't needed
	 * unless the client computer is not NTP-synchronised. */
#if 0
	libnfsnapi_mgr_set_timenudge(mgr, 25);
#endif

	/* TODO: more interesting stuff! */

#if 0
	/* cheat -- not part of the "proper" way of doing things */
	extern int libnfsnapi_mgr_do(libnfsnapi_mgr_t *mgr, int method, const char *request_uri, const char *data);
	libnfsnapi_mgr_do(mgr, 1, "/dns/dagii.org/minTTL", NULL);
#endif

	if (strlen(acct_num) > 0) {
		int tot, high;
		char *name;

		account = libnfsnapi_account_create(mgr, acct_num);
		if (!account) {
			printf("Couldn't create an account!\n");
			goto after_account_test;
		}
		name = libnfsnapi_account_friendlyName(account);

		tot = libnfsnapi_account_balance(account,
						LIBNFSNAPI_BALANCE_ALL);
		high = libnfsnapi_account_balance(account,
						LIBNFSNAPI_BALANCE_HIGH);

		libnfsnapi_account_destroy(account);

		if (tot >= 0 && high >= 0 && name) {
			printf("Balance of account %s ('%s') is $%d.%02d; "
					"highest is $%d.%02d.\n",
					acct_num, name,
					tot / 100, tot % 100,
					high / 100, high % 100);
		} else
			printf("Something died.\n");
		if (name)
			free(name);
	} else {
		printf("Don't have acc. number...\n");
	}
after_account_test:

#if 0
	/* Site testing */
	if (1) {
		libnfsnapi_site_t *site;
		int err;

		site = libnfsnapi_site_create(mgr, "symonds");
		if (!site) {
			printf("Couldn't create an site!\n");
			goto after_site_test;
		}
		printf("Testing site/addAlias...\n");
		err = libnfsnapi_site_addAlias(site, "foo.symonds.id.au");
		if (err)
			printf("Error: %s\n", libnfsnapi_strerror(err));
		else
			printf("Success!\n");

		sleep(2);

		printf("Testing site/removeAlias...\n");
		err = libnfsnapi_site_removeAlias(site, "foo.symonds.id.au");
		if (err)
			printf("Error: %s\n", libnfsnapi_strerror(err));
		else
			printf("Success!\n");

		libnfsnapi_site_destroy(site);
	}
after_site_test:
#endif

	/* final cleanup */
	libnfsnapi_mgr_destroy(mgr);

	return 0;
}
